@@ -24,7 +24,7 @@ class DirectingOtherAnimalsAnalyzer(object):
     Notes
     -----
     Requires the pose-estimation data for the ``left ear``, ``right ear`` and ``nose`` of
-    each individual animals.
+    each individual animals. `GitHub documentation <https://github.com/sgoldenlab/simba/blob/master/docs/ROI_tutorial.md#part-3-generating-features-from-roi-data>`__.
 
     Examples
     -----
@@ -35,8 +35,6 @@ class DirectingOtherAnimalsAnalyzer(object):
     >>> directing_analyzer.summary_statistics()
     """
 
-
-
     def __init__(self,
                  config_path: str):
 
