@@ -64,12 +64,18 @@ class clf_within_ROI(object):
             self.behavior_names.append(self.config.get('SML settings', 'target_name_' + str(i + 1)))
 
     def __inside_rectangle(self, bp_x, bp_y, top_left_x, top_left_y, bottom_right_x, bottom_right_y):
+        """
+        Private helper to calculate if body-part is inside a rectangle.
+        """
         if (((top_left_x) <= bp_x <= (bottom_right_x)) and ((top_left_y) <= bp_y <= (bottom_right_y))):
             return 1
         else:
             return 0
 
     def __inside_circle(self, bp_x, bp_y, center_x, center_y, radius):
+        """
+        Private helper to calculate if body-part is inside a circle.
+        """
         px_dist = int(np.sqrt((bp_x - center_x) ** 2 + (bp_y - center_y) ** 2))
         if px_dist <= radius:
             return 1
@@ -77,12 +83,24 @@ class clf_within_ROI(object):
             return 0
 
     def __inside_polygon(self, bp_x, bp_y, polygon):
+        """
+        Private helper to calculate if body-part is inside a polygon.
+        """
         if polygon.contains(Point(int(bp_x), int(bp_y))):
             return 1
         else:
             return 0
 
     def compute_agg_statistics(self, data: pd.DataFrame):
+        """
+
+        Parameters
+        ----------
+        data: pd.DataFrame
+            Dataframe with boolean columns representing behaviors (behavior present: 1, behavior absent: 0)
+            and ROI data (inside ROI: 1, outside ROI: 0).
+
+        """
         self.results_dict[self.video_name] = {}
         for clf in self.behavior_list:
             self.results_dict[self.video_name][clf] = {}
@@ -101,9 +119,12 @@ class clf_within_ROI(object):
                     start_frames = list(detect_bouts(data_df=data, target_lst=[clf], fps=int(self.fps))['End_frame'])
                     self.results_dict[self.video_name][clf][roi]['Ended bouts by ROI (count)'] = len(data[(data.index.isin(start_frames)) & (data[roi] == 1)])
 
-    def print_missing_roi_warning(self,
+    def __print_missing_roi_warning(self,
                                   roi_type: str,
                                   roi_name: str):
+        """
+        Private helper to print warnings when ROI shapes have been defined in some videos but missing in others.
+        """
         print('SIMBA WARNING: ROI named "{}" of shape type "{}" not found for video {}. Skipping shape...'.format(roi_name, roi_type, self.video_name))
         if roi_type.lower() == 'rectangle': names = list(self.rectangles_df['Name'][self.rectangles_df['Video'] == self.video_name])
         elif roi_type.lower() == 'circle': names = list(self.circles_df['Name'][self.circles_df['Video'] == self.video_name])
@@ -175,7 +196,7 @@ class clf_within_ROI(object):
                     elif roi_type.lower() == 'polygon':
                         shape_info = self.polygon_df.loc[(self.polygon_df['Video'] == self.video_name) & (self.polygon_df['Shape_type'] == roi_type) & (self.polygon_df['Name'] == roi_name)]
                     if len(shape_info) == 0:
-                        self.print_missing_roi_warning(roi_type=roi_type, roi_name=roi_name)
+                        self.__print_missing_roi_warning(roi_type=roi_type, roi_name=roi_name)
                         continue
                     if roi_type.lower() == 'rectangle':
                         data_df['top_left_x'], data_df['top_left_y'] = shape_info['topLeftX'].values[0], shape_info['topLeftY'].values[0]
@@ -202,6 +223,10 @@ class clf_within_ROI(object):
         self.__organize_output_data()
 
     def __organize_output_data(self):
+        """
+        Helper to organize the results[dict] into a human-readable CSV file.
+        """
+
         if len(self.results_dict.keys()) == 0:
             print('SIMBA ERROR: ZERO ROIs found the videos represented in the project_folder/csv/machine_results directory')
             raise ValueError('SIMBA ERROR: ZERO ROIs found the videos represented in the project_folder/csv/machine_results directory')
