@@ -23,7 +23,8 @@ class DataPlotter(object):
         path to SimBA project config file in Configparser format
 
     Notes
-    -----
+    ----------
+    `GitHub tutorial <https://github.com/sgoldenlab/simba/blob/master/docs/Scenario2.md#part-5--visualizing-machine-predictions`__.
 
     Examples
     -----
@@ -31,6 +32,7 @@ class DataPlotter(object):
     >>> data_plotter.process_movement()
     >>> data_plotter.create_data_plots()
     """
+
     def __init__(self,
                  config_path: str,
                  body_part: str=None):
@@ -53,6 +55,9 @@ class DataPlotter(object):
         print('Processing {} video(s)...'.format(str(len(self.files_found))))
 
     def __compute_spacings(self):
+        """
+        Private helper to compute appropriate spacing between printed text.
+        """
         self.loc_dict = {}
         self.loc_dict['Animal'] = (50, 20)
         self.loc_dict['total_movement_header'] = (250, 20)
