@@ -200,12 +200,11 @@ def define_bp_drop_down(configini: str):
 
 
 
-
 def drop_bp_cords(df: pd.DataFrame,
                   config_path: str):
 
     """
-    Removes pose-estimation data from dataframe.
+    Helper to remove pose-estimation data from dataframe.
 
     Parameters
     ----------
@@ -219,10 +218,6 @@ def drop_bp_cords(df: pd.DataFrame,
      out_df: pd.DataFrame
         Dataframe w/o pose-estimation data
 
-
-    Notes
-    -----
-
     Examples
     -----
     >>> df_wo_pose = drop_bp_cords(df='DataFrameWithPose', config_path='MySimBAConfigfile')
@@ -246,6 +241,19 @@ def drop_bp_cords(df: pd.DataFrame,
         print(e.args[0])
 
 def define_movement_cols(multi_animal_id_list: list):
+    """
+    Helper to create column names representing aggregate movement and velocity for each animal in the video.
+
+    Parameters
+    ----------
+    multi_animal_id_list: list
+        list of animal names
+
+    Examples
+    -----
+    >>> column_names = define_movement_cols(multi_animal_id_list=['Animal_1', 'Animal_2' 'Animal_3'])
+    """
+
     columnNames = ['Video', 'Frames processed']
     if len(multi_animal_id_list) == 1:
         columnNames = ['Video', 'Frames processed', 'Total movement (cm)', 'Mean velocity (cm / s)', 'Median velocity (cm/s)']
@@ -266,7 +274,9 @@ def define_movement_cols(multi_animal_id_list: list):
     return columnNames
 
 def bodypartConfSchematic():
-    """Returns the names body-part schematics of all pose-estimation schemas in SimBA installation"""
+    """Helper to return (i) named body-part schematics of all pose-estimation schemas in SimBA installation, and
+    (ii) the paths to the images representing those  body-part schematics in SimBA installation
+    """
 
     optionsBaseListImagesPath = os.path.join(os.path.dirname(__file__), 'pose_configurations', 'schematics')
     optionsBaseListNamesPath = os.path.join(os.path.dirname(__file__), 'pose_configurations', 'configuration_names', 'pose_config_names.csv')
@@ -279,6 +289,9 @@ def bodypartConfSchematic():
 
 
 def GenerateMetaDataFileHeaders():
+    """Helper to return the headings for the SimBA RF model config files."""
+
+
     meta_data_headers = ["Classifier_name", "RF_criterion", "RF_max_features", "RF_min_sample_leaf",
      "RF_n_estimators", "compute_feature_permutation_importance",
      "generate_classification_report", "generate_example_decision_tree",
@@ -307,9 +320,7 @@ def getBpHeaders(inifile: str):
     """
 
     column_headers = []
-    config = ConfigParser()
-    configFile = str(inifile)
-    config.read(configFile)
+    config = read_config_file(inifile)
     project_path = config.get('General settings', 'project_path')
     bodyparthListPath = os.path.join(project_path, 'logs', 'measures', 'pose_configs', 'bp_names','project_bp_names.csv')
     poseConfigDf = pd.read_csv(bodyparthListPath, header=None)
@@ -322,7 +333,7 @@ def getBpHeaders(inifile: str):
 
 def checkDirectionalityCords(animal_bp_dict: dict):
     """
-    Helper to check of ear and nose body-parts are present within the pose-estimation data.
+    Helper to check if ear and nose body-parts are present within the pose-estimation data.
 
     Parameters
     ----------
@@ -361,7 +372,8 @@ def checkDirectionalityCords(animal_bp_dict: dict):
 def createColorListofList(no_animals: int,
                           map_size: int):
     """
-    Creates a list of lists of bgr colors. Each list is a different palette.
+    Helper to return a list of lists of bgr colors. Each list is pulled from a different palette
+    matplotlib color map.
 
     Parameters
     ----------
@@ -384,7 +396,7 @@ def createColorListofList(no_animals: int,
     """
 
     colorListofList = []
-    cmaps = ['spring', 'summer', 'autumn', 'cool', 'Wistia', 'Pastel1', 'Set1', 'winter']
+    cmaps = ['spring', 'summer', 'autumn', 'cool', 'Wistia', 'Pastel1', 'Set1', 'winter', 'afmhot', 'gist_heat', 'copper']
     for colormap in range(no_animals):
         currColorMap = cm.get_cmap(cmaps[colormap], map_size)
         currColorList = []
@@ -469,7 +481,7 @@ def get_fn_ext(filepath: str):
 
 def get_workflow_file_format(config: configparser.ConfigParser):
     """
-    Helper to read the workflow file format in SimBA project.
+    Helper to read the workflow file format in SimBA project. If missing, then defaults to CSV.
 
     Parameters
     ----------
