@@ -113,7 +113,7 @@ class UserDefinedFeatureExtractor(object):
         self.data_df['Sum_probabilities'] = p_df.sum(axis=1)
         self.data_df['Mean_probabilities'] = p_df.mean(axis=1)
 
-        results = pd.DataFrame(self.__count_values_in_range(data=self.out_data.filter(self.pcols).values, ranges=np.array([[0.0, 0.1], [0.000000000, 0.5], [0.000000000, 0.75]])), columns=['Low_prob_detections_0.1', 'Low_prob_detections_0.5','Low_prob_detections_0.75'])
+        results = pd.DataFrame(self.__count_values_in_range(data=self.data_df.filter(self.pcols).values, ranges=np.array([[0.0, 0.1], [0.000000000, 0.5], [0.000000000, 0.75]])), columns=['Low_prob_detections_0.1', 'Low_prob_detections_0.5','Low_prob_detections_0.75'])
         self.out_data = pd.concat([self.data_df, results], axis=1)
 
     def extract_features(self):
