@@ -60,7 +60,7 @@ def _image_creator(frm_range: list=None,
     return img_lst
 
 
-class GanttCreator(object):
+class GanttCreatorMultiprocess(object):
 
     """
     Class for multiprocess creation of classifier gantt charts.
