@@ -61,7 +61,7 @@ class HeatMapperClf(object):
                  palette: str,
                  bodypart: str,
                  clf_name: str,
-                 max_scale: int):
+                 max_scale: int or str):
 
         if (not frame_setting) and (not video_setting) and (not final_img_setting):
             raise ValueError('SIMBA ERROR: Please choose to select either videos, frames, and/or final image.')
@@ -187,7 +187,6 @@ class HeatMapperClf(object):
         print('SIMBA COMPLETE: All heatmap visualizations created in project_folder/frames/output/heatmaps_classifier_locations directory')
 
 
-
 # test = HeatMapperClf(config_path=r'/Users/simon/Desktop/troubleshooting/train_model_project/project_folder/project_config.ini',
 #                  final_img_setting=False,
 #                  video_setting=True,
@@ -196,6 +195,6 @@ class HeatMapperClf(object):
 #                  palette='jet',
 #                  bodypart='Nose_1',
 #                  clf_name='Attack',
-#                  max_scale='auto')
+#                  max_scale=2)
 # test.create_heatmaps()
 
