@@ -10,21 +10,21 @@ def check_int(name, value, max_value=None, min_value=None):
     try:
         t.Int().check(value)
     except t.DataError as e:
-        print('{} {} {}'.format(name, str(value), e.as_dict()))
-        raise ValueError('VALUE ERROR: {} should be an integer in SimBA, but is set to {}'.format(name, str(value)))
+        print('SIMBA VALUE ERROR: {} {} {}'.format(name, str(value), e.as_dict()))
+        raise ValueError('SIMBA VALUE ERROR: {} should be an integer number in SimBA, but is set to {}'.format(name, str(value)))
     if (min_value != None):
         if int(value) < min_value:
-            print(('VALUE ERROR: {} should be more than, or equal {}. It is set to {}'.format(name, str(min_value),
+            print(('SIMBA VALUE ERROR: {} should be more than, or equal {}. It is set to {}'.format(name, str(min_value),
                                                                                               str(value))))
             raise ValueError(
-                'VALUE ERROR: {} should be more than, or equal {}. It is set to {}'.format(name, str(min_value),
+                'SIMBA VALUE ERROR: {} should be more than, or equal {}. It is set to {}'.format(name, str(min_value),
                                                                                            str(value)))
     if (max_value != None):
         if int(value) > max_value:
-            print(('VALUE ERROR: {} should be less than, or equal {}. It is set to {}'.format(name, str(max_value),
+            print(('SIMBA VALUE ERROR: {} should be less than, or equal {}. It is set to {}'.format(name, str(max_value),
                                                                                               str(value))))
             raise ValueError(
-                'VALUE ERROR: {} should be less than, or equal {}. It is set to {}'.format(name, str(max_value),
+                'SIMBA VALUE ERROR: {} should be less than, or equal {}. It is set to {}'.format(name, str(max_value),
                                                                                            str(value)))
 
 
@@ -33,13 +33,13 @@ def check_str(name, value, options=(), allow_blank=False):
         t.String(allow_blank=allow_blank).check(value)
     except t.DataError as e:
         print('{} {} {}'.format(name, str(value), e.as_dict()))
-        raise ValueError('VALUE ERROR: {} should be an string in SimBA, but is set to {}'.format(name, str(value)))
+        raise ValueError('SIMBA VALUE ERROR: {} should be an string in SimBA, but is set to {}'.format(name, str(value)))
     if len(options) > 0:
         if value not in options:
-            print(('VALUE ERROR: {} is set to {} in SimBA, but this is not a valid option {}'.format(name, str(value),
+            print(('SIMBA VALUE ERROR: {} is set to {} in SimBA, but this is not a valid option {}'.format(name, str(value),
                                                                                                      options)))
             raise ValueError(
-                'VALUE ERROR: {} is set to {} in SimBA, but this is not a valid option {}'.format(name, str(value),
+                'SIMBA VALUE ERROR: {} is set to {} in SimBA, but this is not a valid option {}'.format(name, str(value),
                                                                                                   options))
         else:
             pass
@@ -55,18 +55,20 @@ def check_float(name: str,
         t.Float().check(value)
     except t.DataError as e:
         print('{} {} {}'.format(name, str(value), e.as_dict()))
-        print('VALUE ERROR: {} should be a float in SimBA, but is set to {}'.format(name, str(value)))
-        raise ValueError
+        print('SIMBA VALUE ERROR: {} should be a float number in SimBA, but is set to {}'.format(name, str(value)))
+        raise ValueError('SIMBA VALUE ERROR: {} should be a float in SimBA, but is set to {}'.format(name, str(value)))
     if (min_value != None):
         if float(value) < min_value:
-            print('VALUE ERROR: {} should be more than, or equal {}. It is set to {}'.format(name, str(min_value),
+            print('SIMBA VALUE ERROR: {} should be more than, or equal {}. It is set to {}'.format(name, str(min_value),
+                                                                                             str(value)))
+            raise ValueError('SIMBA VALUE ERROR: {} should be more than, or equal {}. It is set to {}'.format(name, str(min_value),
                                                                                              str(value)))
-            raise ValueError
     if (max_value != None):
         if float(value) > max_value:
-            print('VALUE ERROR: {} should be less than, or equal {}. It is set to {}'.format(name, str(max_value),
+            print('SIMBA VALUE ERROR: {} should be less than, or equal {}. It is set to {}'.format(name, str(max_value),
+                                                                                             str(value)))
+            raise ValueError('SIMBA VALUE ERROR: {} should be less than, or equal {}. It is set to {}'.format(name, str(max_value),
                                                                                              str(value)))
-            raise ValueError
 
 
 def read_config_entry(config: ConfigParser,
@@ -166,3 +168,5 @@ def check_that_column_exist(df: pd.DataFrame,
                                                                                                    file_name))
     else:
         pass
+
+
