@@ -1,4 +1,4 @@
-__author__ = "Simon Nilsson", "JJ Choong"
+__author__ = "Simon Nilsson"
 
 import itertools
 from configparser import ConfigParser, MissingSectionHeaderError
@@ -38,7 +38,7 @@ class ImportSLEAP(object):
     config_path: str
         path to SimBA project config file in Configparser format
     data_folder: str
-        Path to folder containing maDLC data in `.h5` format.
+        Path to folder containing SLEAP data in `.slp` format.
     actor_IDs: list
         List of animal names.
     interpolation_settings: str
@@ -49,11 +49,6 @@ class ImportSLEAP(object):
         Dictionary defining the pose estimation smoothing method. EXAMPLE: {'Method': 'Savitzky Golay',
         'Parameters': {'Time_window': '200'}})
 
-    Notes
-    -----
-    `Multi-animal import tutorial <https://github.com/sgoldenlab/simba/blob/master/docs/Multi_animal_pose.md>`__.
-
-
     Example
     ----------
     >>> slp_importer = ImportSLEAP(project_path="MyConfigPath", data_folder=r'MySLPDataFolder', actor_IDs=['Mouse_1', 'Mouse_2'], interpolation_settings="Body-parts: Nearest", smoothing_settings = {'Method': 'Savitzky Golay', 'Parameters': {'Time_window': '200'}})
@@ -64,7 +59,8 @@ class ImportSLEAP(object):
     """
 
 
-    def __init__(self, project_path: str,
+    def __init__(self,
+                 project_path: str,
                  data_folder: str,
                  actor_IDs: list,
                  interpolation_settings: str,
@@ -223,6 +219,7 @@ class ImportSLEAP(object):
             self.analysis_dict['animals_in_each_frame'] = [x[4] - x[3] for x in frames_lst]
             self.__create_tracks()
 
+
     def __check_that_all_animals_exist_in_frame(self):
         existing_animals = list(self.frame_dict.keys())
         missing_animals = [x for x in range(self.animals_no) if x not in existing_animals]
@@ -232,7 +229,6 @@ class ImportSLEAP(object):
     def __create_tracks(self):
         start_frame = 0
         for frame_cnt, frame in enumerate(range(self.analysis_dict['no_frames'])):
-        #for frame_cnt, frame in enumerate(range(0, 500)):
             frame_idx = self.analysis_dict['frames'][frame_cnt][2]
             self.frame_dict = {}
             print('Frame: {}/{}, Video: {} ({}/{})'.format(str(frame_cnt), str(self.analysis_dict['no_frames']), str(self.video_name), str(self.video_counter + 1), str(len(self.files_found))))
